diff --git a/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlayDrawableDpad.java b/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlayDrawableDpad.java
index d8ee6895b..aa3653e09 100644
--- a/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlayDrawableDpad.java
+++ b/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlayDrawableDpad.java
@@ -178,7 +178,7 @@ public final class InputOverlayDrawableDpad {
// Pressed up right
if (mUpButtonState && !mLeftButtonState && mRightButtonState) {
canvas.save();
- canvas.rotate(180, px, py);
+ canvas.rotate(90, px, py);
mPressedTwoDirectionsStateBitmap.draw(canvas);
canvas.restore();
return;
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_a.png b/src/android/app/src/main/res/drawable-hdpi/button_a.png
deleted file mode 100644
index f96a2061e..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_a.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_a_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_a_pressed.png
deleted file mode 100644
index 785a258ee..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_a_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_b.png b/src/android/app/src/main/res/drawable-hdpi/button_b.png
deleted file mode 100644
index b15d2b549..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_b.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_b_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_b_pressed.png
deleted file mode 100644
index b11d5fcee..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_b_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_l.png b/src/android/app/src/main/res/drawable-hdpi/button_l.png
deleted file mode 100644
index e19469a7b..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_l.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_l_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_l_pressed.png
deleted file mode 100644
index 280857f64..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_l_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_r.png b/src/android/app/src/main/res/drawable-hdpi/button_r.png
deleted file mode 100644
index f72cdc1dc..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_r.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_r_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_r_pressed.png
deleted file mode 100644
index c47d34253..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_r_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_select.png b/src/android/app/src/main/res/drawable-hdpi/button_select.png
deleted file mode 100644
index 6961b88d2..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_select.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_select_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_select_pressed.png
deleted file mode 100644
index 8ee471419..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_select_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_start.png b/src/android/app/src/main/res/drawable-hdpi/button_start.png
deleted file mode 100644
index 72856cf47..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_start.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_start_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_start_pressed.png
deleted file mode 100644
index f96cd3359..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_start_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_x.png b/src/android/app/src/main/res/drawable-hdpi/button_x.png
deleted file mode 100644
index 1a0fd1924..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_x.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_x_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_x_pressed.png
deleted file mode 100644
index 089cb3af1..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_x_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_y.png b/src/android/app/src/main/res/drawable-hdpi/button_y.png
deleted file mode 100644
index bc22680c4..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_y.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_y_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_y_pressed.png
deleted file mode 100644
index 6e9e89ec9..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_y_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_zl.png b/src/android/app/src/main/res/drawable-hdpi/button_zl.png
deleted file mode 100644
index dd5d4d5b3..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_zl.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_zl_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_zl_pressed.png
deleted file mode 100644
index 8cd395f3b..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_zl_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_zr.png b/src/android/app/src/main/res/drawable-hdpi/button_zr.png
deleted file mode 100644
index 728fcf4d1..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_zr.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/button_zr_pressed.png b/src/android/app/src/main/res/drawable-hdpi/button_zr_pressed.png
deleted file mode 100644
index 121877610..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/button_zr_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/dpad.png b/src/android/app/src/main/res/drawable-hdpi/dpad.png
deleted file mode 100644
index 921b3902d..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/dpad.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_one_direction.png b/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_one_direction.png
deleted file mode 100644
index a8ffbb48a..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_one_direction.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_two_directions.png b/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_two_directions.png
deleted file mode 100644
index ceb994a6d..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/dpad_pressed_two_directions.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_c.png b/src/android/app/src/main/res/drawable-hdpi/stick_c.png
deleted file mode 100644
index d4c1d6c97..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_c.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_c_pressed.png b/src/android/app/src/main/res/drawable-hdpi/stick_c_pressed.png
deleted file mode 100644
index c8d14c029..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_c_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_c_range.png b/src/android/app/src/main/res/drawable-hdpi/stick_c_range.png
deleted file mode 100644
index 8263d4b8d..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_c_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_main.png b/src/android/app/src/main/res/drawable-hdpi/stick_main.png
deleted file mode 100644
index ae6d025a5..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_main.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_main_pressed.png b/src/android/app/src/main/res/drawable-hdpi/stick_main_pressed.png
deleted file mode 100644
index ca469c6a7..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_main_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-hdpi/stick_main_range.png b/src/android/app/src/main/res/drawable-hdpi/stick_main_range.png
deleted file mode 100644
index 9b5445edc..000000000
Binary files a/src/android/app/src/main/res/drawable-hdpi/stick_main_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_a.png b/src/android/app/src/main/res/drawable-xhdpi/button_a.png
deleted file mode 100644
index 4e20f2b0e..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_a.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_a_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_a_pressed.png
deleted file mode 100644
index f18edd07e..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_a_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_b.png b/src/android/app/src/main/res/drawable-xhdpi/button_b.png
deleted file mode 100644
index deb83a09d..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_b.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_b_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_b_pressed.png
deleted file mode 100644
index f583be028..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_b_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_l.png b/src/android/app/src/main/res/drawable-xhdpi/button_l.png
deleted file mode 100644
index d24039fbf..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_l.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_l_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_l_pressed.png
deleted file mode 100644
index 378ac8751..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_l_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_r.png b/src/android/app/src/main/res/drawable-xhdpi/button_r.png
deleted file mode 100644
index 7b01c043e..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_r.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_r_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_r_pressed.png
deleted file mode 100644
index 9b3e3e75a..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_r_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_select.png b/src/android/app/src/main/res/drawable-xhdpi/button_select.png
deleted file mode 100644
index 57abf5666..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_select.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_select_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_select_pressed.png
deleted file mode 100644
index 29eda72af..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_select_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_start.png b/src/android/app/src/main/res/drawable-xhdpi/button_start.png
deleted file mode 100644
index f9cf0d667..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_start.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_start_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_start_pressed.png
deleted file mode 100644
index 4d690fa7e..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_start_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_x.png b/src/android/app/src/main/res/drawable-xhdpi/button_x.png
deleted file mode 100644
index 93a2ee997..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_x.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_x_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_x_pressed.png
deleted file mode 100644
index 6bbd39646..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_x_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_y.png b/src/android/app/src/main/res/drawable-xhdpi/button_y.png
deleted file mode 100644
index d979e98e0..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_y.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_y_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_y_pressed.png
deleted file mode 100644
index a6c9bdb54..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_y_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_zl.png b/src/android/app/src/main/res/drawable-xhdpi/button_zl.png
deleted file mode 100644
index f94474fea..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_zl.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_zl_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_zl_pressed.png
deleted file mode 100644
index 8f7d5ab7a..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_zl_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_zr.png b/src/android/app/src/main/res/drawable-xhdpi/button_zr.png
deleted file mode 100644
index a76658351..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_zr.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/button_zr_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/button_zr_pressed.png
deleted file mode 100644
index bbe4e64ce..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/button_zr_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/dpad.png b/src/android/app/src/main/res/drawable-xhdpi/dpad.png
deleted file mode 100644
index 94ae84405..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/dpad.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_one_direction.png b/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_one_direction.png
deleted file mode 100644
index d6ccb2c4f..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_one_direction.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_two_directions.png b/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_two_directions.png
deleted file mode 100644
index 2bba7749e..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/dpad_pressed_two_directions.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_c.png b/src/android/app/src/main/res/drawable-xhdpi/stick_c.png
deleted file mode 100644
index 7819f220a..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_c.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_c_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/stick_c_pressed.png
deleted file mode 100644
index a111c2ac7..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_c_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_c_range.png b/src/android/app/src/main/res/drawable-xhdpi/stick_c_range.png
deleted file mode 100644
index 774c54292..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_c_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_main.png b/src/android/app/src/main/res/drawable-xhdpi/stick_main.png
deleted file mode 100644
index 3f80cdf6c..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_main.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_main_pressed.png b/src/android/app/src/main/res/drawable-xhdpi/stick_main_pressed.png
deleted file mode 100644
index 2a7675ef7..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_main_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xhdpi/stick_main_range.png b/src/android/app/src/main/res/drawable-xhdpi/stick_main_range.png
deleted file mode 100644
index ca1672caf..000000000
Binary files a/src/android/app/src/main/res/drawable-xhdpi/stick_main_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_a.png b/src/android/app/src/main/res/drawable-xxhdpi/button_a.png
deleted file mode 100644
index 999b4c01e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_a.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_a_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_a_pressed.png
deleted file mode 100644
index bb4de9bd9..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_a_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_b.png b/src/android/app/src/main/res/drawable-xxhdpi/button_b.png
deleted file mode 100644
index 8ed042e7e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_b.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_b_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_b_pressed.png
deleted file mode 100644
index 86f5d535e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_b_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_l.png b/src/android/app/src/main/res/drawable-xxhdpi/button_l.png
deleted file mode 100644
index 9572c66f8..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_l.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_l_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_l_pressed.png
deleted file mode 100644
index 64bedc326..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_l_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_r.png b/src/android/app/src/main/res/drawable-xxhdpi/button_r.png
deleted file mode 100644
index abbcadede..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_r.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_r_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_r_pressed.png
deleted file mode 100644
index 07421767f..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_r_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_select.png b/src/android/app/src/main/res/drawable-xxhdpi/button_select.png
deleted file mode 100644
index 42c3b7c43..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_select.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_select_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_select_pressed.png
deleted file mode 100644
index 0d1e56f6a..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_select_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_start.png b/src/android/app/src/main/res/drawable-xxhdpi/button_start.png
deleted file mode 100644
index 4e9585bb4..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_start.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_start_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_start_pressed.png
deleted file mode 100644
index 8c089e237..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_start_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_x.png b/src/android/app/src/main/res/drawable-xxhdpi/button_x.png
deleted file mode 100644
index 0500f964f..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_x.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_x_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_x_pressed.png
deleted file mode 100644
index 56db5843d..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_x_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_y.png b/src/android/app/src/main/res/drawable-xxhdpi/button_y.png
deleted file mode 100644
index 53c5ca084..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_y.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_y_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_y_pressed.png
deleted file mode 100644
index 5d91cbfb0..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_y_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_zl.png b/src/android/app/src/main/res/drawable-xxhdpi/button_zl.png
deleted file mode 100644
index f8ce9a0c6..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_zl.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_zl_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_zl_pressed.png
deleted file mode 100644
index 981c8b0c8..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_zl_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_zr.png b/src/android/app/src/main/res/drawable-xxhdpi/button_zr.png
deleted file mode 100644
index 82065e126..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_zr.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/button_zr_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/button_zr_pressed.png
deleted file mode 100644
index b30b2e799..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/button_zr_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/dpad.png b/src/android/app/src/main/res/drawable-xxhdpi/dpad.png
deleted file mode 100644
index 36b7ea183..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/dpad.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_one_direction.png b/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_one_direction.png
deleted file mode 100644
index 3715e1c11..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_one_direction.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_two_directions.png b/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_two_directions.png
deleted file mode 100644
index fb0d7fc5c..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/dpad_pressed_two_directions.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_c.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_c.png
deleted file mode 100644
index e950c5b15..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_c.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_c_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_c_pressed.png
deleted file mode 100644
index 3ac88ed9b..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_c_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_c_range.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_c_range.png
deleted file mode 100644
index a3491c80f..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_c_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_main.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_main.png
deleted file mode 100644
index 16ca58c0f..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_main.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_main_pressed.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_main_pressed.png
deleted file mode 100644
index e7fe0c2d5..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_main_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxhdpi/stick_main_range.png b/src/android/app/src/main/res/drawable-xxhdpi/stick_main_range.png
deleted file mode 100644
index 8c47b2ba3..000000000
Binary files a/src/android/app/src/main/res/drawable-xxhdpi/stick_main_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_a.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_a.png
deleted file mode 100644
index e364fae1e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_a.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_a_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_a_pressed.png
deleted file mode 100644
index 08d65cc99..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_a_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_b.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_b.png
deleted file mode 100644
index faae9b6f7..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_b.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_b_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_b_pressed.png
deleted file mode 100644
index 669780f28..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_b_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_l.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_l.png
deleted file mode 100644
index 888b147de..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_l.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_l_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_l_pressed.png
deleted file mode 100644
index 605493e3e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_l_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_r.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_r.png
deleted file mode 100644
index 90a93af8d..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_r.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_r_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_r_pressed.png
deleted file mode 100644
index 4500cd2be..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_r_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_select.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_select.png
deleted file mode 100644
index b18b2fd59..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_select.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_select_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_select_pressed.png
deleted file mode 100644
index 53ed400e0..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_select_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_start.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_start.png
deleted file mode 100644
index c55e56852..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_start.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_start_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_start_pressed.png
deleted file mode 100644
index 1507cc365..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_start_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_x.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_x.png
deleted file mode 100644
index 7ef2b883e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_x.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_x_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_x_pressed.png
deleted file mode 100644
index f3f11ede2..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_x_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_y.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_y.png
deleted file mode 100644
index 4ce679c69..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_y.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_y_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_y_pressed.png
deleted file mode 100644
index 926f5e269..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_y_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_zl.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_zl.png
deleted file mode 100644
index 7faf8db3b..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_zl.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_zl_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_zl_pressed.png
deleted file mode 100644
index cc56a749c..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_zl_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_zr.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_zr.png
deleted file mode 100644
index ed1b6b683..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_zr.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/button_zr_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/button_zr_pressed.png
deleted file mode 100644
index 892fa74f1..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/button_zr_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/dpad.png b/src/android/app/src/main/res/drawable-xxxhdpi/dpad.png
deleted file mode 100644
index 6272f39e6..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/dpad.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_one_direction.png b/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_one_direction.png
deleted file mode 100644
index 0cccd3a30..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_one_direction.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_two_directions.png b/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_two_directions.png
deleted file mode 100644
index 18a99ad2d..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/dpad_pressed_two_directions.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_c.png
deleted file mode 100644
index 88e09b8a0..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_pressed.png
deleted file mode 100644
index edc920e8e..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_range.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_range.png
deleted file mode 100644
index a8b693494..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_c_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_main.png
deleted file mode 100644
index d157edca2..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_pressed.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_pressed.png
deleted file mode 100644
index 2ac2440be..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_pressed.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_range.png b/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_range.png
deleted file mode 100644
index 71e67e02a..000000000
Binary files a/src/android/app/src/main/res/drawable-xxxhdpi/stick_main_range.png and /dev/null differ
diff --git a/src/android/app/src/main/res/drawable/dpad_standard.xml b/src/android/app/src/main/res/drawable/dpad_standard.xml
new file mode 100644
index 000000000..28aba657e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/dpad_standard.xml
@@ -0,0 +1,24 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/dpad_standard_cardinal_depressed.xml b/src/android/app/src/main/res/drawable/dpad_standard_cardinal_depressed.xml
new file mode 100644
index 000000000..5eeb51dbe
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/dpad_standard_cardinal_depressed.xml
@@ -0,0 +1,24 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/dpad_standard_diagonal_depressed.xml b/src/android/app/src/main/res/drawable/dpad_standard_diagonal_depressed.xml
new file mode 100644
index 000000000..520fd447c
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/dpad_standard_diagonal_depressed.xml
@@ -0,0 +1,24 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_a.xml b/src/android/app/src/main/res/drawable/facebutton_a.xml
new file mode 100644
index 000000000..668652edb
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_a.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_a_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_a_depressed.xml
new file mode 100644
index 000000000..4fbe06962
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_a_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_b.xml b/src/android/app/src/main/res/drawable/facebutton_b.xml
new file mode 100644
index 000000000..8912219ca
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_b.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_b_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_b_depressed.xml
new file mode 100644
index 000000000..012abeaf1
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_b_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_home.xml b/src/android/app/src/main/res/drawable/facebutton_home.xml
new file mode 100644
index 000000000..03596ec2e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_home.xml
@@ -0,0 +1,21 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_home_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_home_depressed.xml
new file mode 100644
index 000000000..cde7c6a9e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_home_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_minus.xml b/src/android/app/src/main/res/drawable/facebutton_minus.xml
new file mode 100644
index 000000000..4296b4fcc
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_minus.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_minus_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_minus_depressed.xml
new file mode 100644
index 000000000..628027841
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_minus_depressed.xml
@@ -0,0 +1,9 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_plus.xml b/src/android/app/src/main/res/drawable/facebutton_plus.xml
new file mode 100644
index 000000000..43ae14365
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_plus.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_plus_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_plus_depressed.xml
new file mode 100644
index 000000000..c510e136e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_plus_depressed.xml
@@ -0,0 +1,9 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_screenshot.xml b/src/android/app/src/main/res/drawable/facebutton_screenshot.xml
new file mode 100644
index 000000000..984b4fd02
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_screenshot.xml
@@ -0,0 +1,21 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_screenshot_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_screenshot_depressed.xml
new file mode 100644
index 000000000..fd2e44294
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_screenshot_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_x.xml b/src/android/app/src/main/res/drawable/facebutton_x.xml
new file mode 100644
index 000000000..43fdd14c4
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_x.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_x_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_x_depressed.xml
new file mode 100644
index 000000000..a9ba49169
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_x_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_y.xml b/src/android/app/src/main/res/drawable/facebutton_y.xml
new file mode 100644
index 000000000..980be3b2e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_y.xml
@@ -0,0 +1,22 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/facebutton_y_depressed.xml b/src/android/app/src/main/res/drawable/facebutton_y_depressed.xml
new file mode 100644
index 000000000..320d63897
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/facebutton_y_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/joystick.xml b/src/android/app/src/main/res/drawable/joystick.xml
new file mode 100644
index 000000000..bdd071212
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/joystick.xml
@@ -0,0 +1,45 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/joystick_depressed.xml b/src/android/app/src/main/res/drawable/joystick_depressed.xml
new file mode 100644
index 000000000..ad51d73ce
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/joystick_depressed.xml
@@ -0,0 +1,10 @@
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/joystick_range.xml b/src/android/app/src/main/res/drawable/joystick_range.xml
new file mode 100644
index 000000000..cdd5d2e50
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/joystick_range.xml
@@ -0,0 +1,38 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/l_shoulder.xml b/src/android/app/src/main/res/drawable/l_shoulder.xml
new file mode 100644
index 000000000..28f9a9950
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/l_shoulder.xml
@@ -0,0 +1,23 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/l_shoulder_depressed.xml b/src/android/app/src/main/res/drawable/l_shoulder_depressed.xml
new file mode 100644
index 000000000..2f9a1fd7e
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/l_shoulder_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/r_shoulder.xml b/src/android/app/src/main/res/drawable/r_shoulder.xml
new file mode 100644
index 000000000..97731cad2
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/r_shoulder.xml
@@ -0,0 +1,23 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/r_shoulder_depressed.xml b/src/android/app/src/main/res/drawable/r_shoulder_depressed.xml
new file mode 100644
index 000000000..e3aa46aa1
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/r_shoulder_depressed.xml
@@ -0,0 +1,8 @@
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/zl_trigger.xml b/src/android/app/src/main/res/drawable/zl_trigger.xml
new file mode 100644
index 000000000..436461c3b
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/zl_trigger.xml
@@ -0,0 +1,25 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/zl_trigger_depressed.xml b/src/android/app/src/main/res/drawable/zl_trigger_depressed.xml
new file mode 100644
index 000000000..00393c04d
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/zl_trigger_depressed.xml
@@ -0,0 +1,10 @@
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/zr_trigger.xml b/src/android/app/src/main/res/drawable/zr_trigger.xml
new file mode 100644
index 000000000..2b3a92184
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/zr_trigger.xml
@@ -0,0 +1,25 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/src/android/app/src/main/res/drawable/zr_trigger_depressed.xml b/src/android/app/src/main/res/drawable/zr_trigger_depressed.xml
new file mode 100644
index 000000000..8a9ee5036
--- /dev/null
+++ b/src/android/app/src/main/res/drawable/zr_trigger_depressed.xml
@@ -0,0 +1,10 @@
+
+
+
+
+
diff --git a/src/android/app/src/main/res/values/integers.xml b/src/android/app/src/main/res/values/integers.xml
index 2d750d89a..6e81215a5 100644
--- a/src/android/app/src/main/res/values/integers.xml
+++ b/src/android/app/src/main/res/values/integers.xml
@@ -17,13 +17,13 @@
715
740
13
- 0
+ 125
895
- 0
+ 125
13
- 115
+ 0
895
- 115
+ 0
440
850
520
diff --git a/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlay.java b/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlay.java
index 881c6de91..76c437cb9 100644
--- a/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlay.java
+++ b/src/android/app/src/main/java/org/yuzu/yuzu_emu/overlay/InputOverlay.java
@@ -15,7 +15,9 @@ import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Rect;
+import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
+import android.graphics.drawable.VectorDrawable;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
@@ -29,6 +31,8 @@ import android.view.SurfaceView;
import android.view.View;
import android.view.View.OnTouchListener;
+import androidx.core.content.ContextCompat;
+
import org.yuzu.yuzu_emu.NativeLibrary;
import org.yuzu.yuzu_emu.NativeLibrary.ButtonType;
import org.yuzu.yuzu_emu.NativeLibrary.StickType;
@@ -103,21 +107,28 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
/**
* Resizes a {@link Bitmap} by a given scale factor
*
* @param context The current {@link Context}
* @param bitmap The {@link Bitmap} to scale.
* @param scale The scale factor for the bitmap.
* @return The scaled {@link Bitmap}
*/
- public static Bitmap resizeBitmap(Context context, Bitmap bitmap, float scale) {
- // Determine the button size based on the smaller screen dimension.
- // This makes sure the buttons are the same size in both portrait and landscape.
- DisplayMetrics dm = context.getResources().getDisplayMetrics();
- int minDimension = Math.min(dm.widthPixels, dm.heightPixels);
+ private static Bitmap getBitmap(VectorDrawable vectorDrawable, float scale) {
+ Bitmap bitmap = Bitmap.createBitmap((int) (vectorDrawable.getIntrinsicWidth() * scale),
+ (int) (vectorDrawable.getIntrinsicHeight() * scale), Bitmap.Config.ARGB_8888);
+ Canvas canvas = new Canvas(bitmap);
+ vectorDrawable.setBounds(0, 0, canvas.getWidth(), canvas.getHeight());
+ vectorDrawable.draw(canvas);
+ return bitmap;
+ }
- return Bitmap.createScaledBitmap(bitmap,
- (int) (minDimension * scale),
- (int) (minDimension * scale),
- true);
+ private static Bitmap getBitmap(Context context, int drawableId, float scale) {
+ Drawable drawable = ContextCompat.getDrawable(context, drawableId);
+ if (drawable instanceof BitmapDrawable) {
+ return BitmapFactory.decodeResource(context.getResources(), drawableId);
+ } else if (drawable instanceof VectorDrawable) {
+ return getBitmap((VectorDrawable) drawable, scale);
+ } else {
+ throw new IllegalArgumentException("unsupported drawable type");
+ }
}
/**
@@ -166,16 +177,16 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
case ButtonType.BUTTON_CAPTURE:
case ButtonType.BUTTON_PLUS:
case ButtonType.BUTTON_MINUS:
- scale = 0.08f;
+ scale = 0.35f;
break;
case ButtonType.TRIGGER_L:
case ButtonType.TRIGGER_R:
case ButtonType.TRIGGER_ZL:
case ButtonType.TRIGGER_ZR:
- scale = 0.18f;
+ scale = 0.38f;
break;
default:
- scale = 0.11f;
+ scale = 0.40f;
break;
}
@@ -183,10 +194,8 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
scale /= 100;
// Initialize the InputOverlayDrawableButton.
- final Bitmap defaultStateBitmap =
- resizeBitmap(context, BitmapFactory.decodeResource(res, defaultResId), scale);
- final Bitmap pressedStateBitmap =
- resizeBitmap(context, BitmapFactory.decodeResource(res, pressedResId), scale);
+ final Bitmap defaultStateBitmap = getBitmap(context, defaultResId, scale);
+ final Bitmap pressedStateBitmap = getBitmap(context, pressedResId, scale);
final InputOverlayDrawableButton overlayDrawable =
new InputOverlayDrawableButton(res, defaultStateBitmap, pressedStateBitmap, buttonId);
@@ -243,20 +252,17 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
final SharedPreferences sPrefs = PreferenceManager.getDefaultSharedPreferences(context);
// Decide scale based on button ID and user preference
- float scale = 0.23f;
+ float scale = 0.40f;
scale *= (sPrefs.getInt("controlScale", 50) + 50);
scale /= 100;
// Initialize the InputOverlayDrawableDpad.
- final Bitmap defaultStateBitmap =
- resizeBitmap(context, BitmapFactory.decodeResource(res, defaultResId), scale);
- final Bitmap pressedOneDirectionStateBitmap =
- resizeBitmap(context, BitmapFactory.decodeResource(res, pressedOneDirectionResId),
- scale);
- final Bitmap pressedTwoDirectionsStateBitmap =
- resizeBitmap(context, BitmapFactory.decodeResource(res, pressedTwoDirectionsResId),
- scale);
+ final Bitmap defaultStateBitmap = getBitmap(context, defaultResId, scale);
+ final Bitmap pressedOneDirectionStateBitmap = getBitmap(context, pressedOneDirectionResId,
+ scale);
+ final Bitmap pressedTwoDirectionsStateBitmap = getBitmap(context, pressedTwoDirectionsResId,
+ scale);
final InputOverlayDrawableDpad overlayDrawable =
new InputOverlayDrawableDpad(res, defaultStateBitmap,
pressedOneDirectionStateBitmap, pressedTwoDirectionsStateBitmap,
@@ -300,15 +306,14 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
final SharedPreferences sPrefs = PreferenceManager.getDefaultSharedPreferences(context);
// Decide scale based on user preference
- float scale = 0.275f;
+ float scale = 0.35f;
scale *= (sPrefs.getInt("controlScale", 50) + 50);
scale /= 100;
// Initialize the InputOverlayDrawableJoystick.
- final Bitmap bitmapOuter =
- resizeBitmap(context, BitmapFactory.decodeResource(res, resOuter), scale);
- final Bitmap bitmapInnerDefault = BitmapFactory.decodeResource(res, defaultResInner);
- final Bitmap bitmapInnerPressed = BitmapFactory.decodeResource(res, pressedResInner);
+ final Bitmap bitmapOuter = getBitmap(context, resOuter, scale);
+ final Bitmap bitmapInnerDefault = getBitmap(context, defaultResInner, 1.0f);
+ final Bitmap bitmapInnerPressed = getBitmap(context, pressedResInner, 1.0f);
// The X and Y coordinates of the InputOverlayDrawableButton on the InputOverlay.
// These were set in the input overlay configuration menu.
@@ -320,7 +325,7 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
// Now set the bounds for the InputOverlayDrawableJoystick.
// This will dictate where on the screen (and the what the size) the InputOverlayDrawableJoystick will be.
int outerSize = bitmapOuter.getWidth();
- Rect outerRect = new Rect(drawableX, drawableY, drawableX + (int) (outerSize / outerScale), drawableY + (int) (outerSize / outerScale));
+ Rect outerRect = new Rect(drawableX, drawableY, drawableX + outerSize, drawableY + outerSize);
Rect innerRect = new Rect(0, 0, (int) (outerSize / outerScale), (int) (outerSize / outerScale));
// Send the drawableId to the joystick so it can be referenced when saving control position.
@@ -476,68 +481,68 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
private void addOverlayControls(String orientation) {
if (mPreferences.getBoolean("buttonToggle0", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_a,
- R.drawable.button_a_pressed, ButtonType.BUTTON_A, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_a,
+ R.drawable.facebutton_a_depressed, ButtonType.BUTTON_A, orientation));
}
if (mPreferences.getBoolean("buttonToggle1", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_b,
- R.drawable.button_b_pressed, ButtonType.BUTTON_B, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_b,
+ R.drawable.facebutton_b_depressed, ButtonType.BUTTON_B, orientation));
}
if (mPreferences.getBoolean("buttonToggle2", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_x,
- R.drawable.button_x_pressed, ButtonType.BUTTON_X, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_x,
+ R.drawable.facebutton_x_depressed, ButtonType.BUTTON_X, orientation));
}
if (mPreferences.getBoolean("buttonToggle3", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_y,
- R.drawable.button_y_pressed, ButtonType.BUTTON_Y, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_y,
+ R.drawable.facebutton_y_depressed, ButtonType.BUTTON_Y, orientation));
}
if (mPreferences.getBoolean("buttonToggle4", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_l,
- R.drawable.button_l_pressed, ButtonType.TRIGGER_L, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.l_shoulder,
+ R.drawable.l_shoulder_depressed, ButtonType.TRIGGER_L, orientation));
}
if (mPreferences.getBoolean("buttonToggle5", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_r,
- R.drawable.button_r_pressed, ButtonType.TRIGGER_R, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.r_shoulder,
+ R.drawable.r_shoulder_depressed, ButtonType.TRIGGER_R, orientation));
}
if (mPreferences.getBoolean("buttonToggle6", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_zl,
- R.drawable.button_zl_pressed, ButtonType.TRIGGER_ZL, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.zl_trigger,
+ R.drawable.zl_trigger_depressed, ButtonType.TRIGGER_ZL, orientation));
}
if (mPreferences.getBoolean("buttonToggle7", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_zr,
- R.drawable.button_zr_pressed, ButtonType.TRIGGER_ZR, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.zr_trigger,
+ R.drawable.zr_trigger_depressed, ButtonType.TRIGGER_ZR, orientation));
}
if (mPreferences.getBoolean("buttonToggle8", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_start,
- R.drawable.button_start_pressed, ButtonType.BUTTON_PLUS, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_plus,
+ R.drawable.facebutton_plus_depressed, ButtonType.BUTTON_PLUS, orientation));
}
if (mPreferences.getBoolean("buttonToggle9", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_select,
- R.drawable.button_select_pressed, ButtonType.BUTTON_MINUS, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_minus,
+ R.drawable.facebutton_minus_depressed, ButtonType.BUTTON_MINUS, orientation));
}
if (mPreferences.getBoolean("buttonToggle10", true)) {
- overlayDpads.add(initializeOverlayDpad(getContext(), R.drawable.dpad,
- R.drawable.dpad_pressed_one_direction,
- R.drawable.dpad_pressed_two_directions,
+ overlayDpads.add(initializeOverlayDpad(getContext(), R.drawable.dpad_standard,
+ R.drawable.dpad_standard_cardinal_depressed,
+ R.drawable.dpad_standard_diagonal_depressed,
ButtonType.DPAD_UP, ButtonType.DPAD_DOWN,
ButtonType.DPAD_LEFT, ButtonType.DPAD_RIGHT, orientation));
}
if (mPreferences.getBoolean("buttonToggle11", true)) {
- overlayJoysticks.add(initializeOverlayJoystick(getContext(), R.drawable.stick_main_range,
- R.drawable.stick_main, R.drawable.stick_main_pressed,
+ overlayJoysticks.add(initializeOverlayJoystick(getContext(), R.drawable.joystick_range,
+ R.drawable.joystick, R.drawable.joystick_depressed,
StickType.STICK_L, ButtonType.STICK_L, orientation));
}
if (mPreferences.getBoolean("buttonToggle12", true)) {
- overlayJoysticks.add(initializeOverlayJoystick(getContext(), R.drawable.stick_main_range,
- R.drawable.stick_main, R.drawable.stick_main_pressed, StickType.STICK_R, ButtonType.STICK_R, orientation));
+ overlayJoysticks.add(initializeOverlayJoystick(getContext(), R.drawable.joystick_range,
+ R.drawable.joystick, R.drawable.joystick_depressed, StickType.STICK_R, ButtonType.STICK_R, orientation));
}
if (mPreferences.getBoolean("buttonToggle13", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_a,
- R.drawable.button_a, ButtonType.BUTTON_HOME, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_home,
+ R.drawable.facebutton_home_depressed, ButtonType.BUTTON_HOME, orientation));
}
if (mPreferences.getBoolean("buttonToggle14", true)) {
- overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.button_a,
- R.drawable.button_a, ButtonType.BUTTON_CAPTURE, orientation));
+ overlayButtons.add(initializeOverlayButton(getContext(), R.drawable.facebutton_screenshot,
+ R.drawable.facebutton_screenshot_depressed, ButtonType.BUTTON_CAPTURE, orientation));
}
}
@@ -103,21 +107,28 @@ public final class InputOverlay extends SurfaceView implements OnTouchListener,
* Resizes a {@link Bitmap} by a given scale factor
*
- * @param context The current {@link Context}
- * @param bitmap The {@link Bitmap} to scale.
- * @param scale The scale factor for the bitmap.
+ * @param vectorDrawable The {@link Bitmap} to scale.
+ * @param scale The scale factor for the bitmap.
* @return The scaled {@link Bitmap}
*/